You are viewing a plain text version of this content. The canonical link for it is here.
Posted to adffaces-commits@incubator.apache.org by ma...@apache.org on 2006/07/27 03:39:51 UTC

svn commit: r425942 [6/15] - in /incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src: main/java/org/apache/myfaces/trinidadinternal/agent/ main/java/org/apache/myfaces/trinidadinternal/agent/parse/ main/java/org/apache/my...

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputDocumentRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputDocumentRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputDocumentRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputDocumentRenderer.java Wed Jul 26 20:39:26 2006
@@ -29,7 +29,7 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.output.CoreOutputDocument;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 /**
  * @author Simon Lessard, Fujitsu Consulting
@@ -47,7 +47,7 @@
   @Override
   protected void encodeBegin(
       FacesContext context,
-      AdfRenderingContext arc,
+      RenderingContext arc,
       UIComponent comp,
       FacesBean bean) throws IOException
   {
@@ -64,7 +64,7 @@
   @Override
   public void encodeEnd(
       FacesContext context,
-      AdfRenderingContext arc,
+      RenderingContext arc,
       UIComponent comp,
       FacesBean bean) throws IOException
   {
@@ -171,7 +171,7 @@
   @Override
   protected void renderStyleAttributes(
       FacesContext context,
-      AdfRenderingContext arc,
+      RenderingContext arc,
       FacesBean bean) throws IOException
   {
     renderStyleAttributes(context, arc, bean, _ROOT_SELECTOR);
@@ -191,7 +191,7 @@
    * @return the array of style classes to add to the current facet.
    */
   private String[] _getStyleClasses(
-      AdfRenderingContext arc,
+      RenderingContext arc,
       FacesBean bean,
       PropertyKey key,
       String skinSelector)
@@ -264,7 +264,7 @@
    */
   private void _renderParagraphStart(
       FacesContext context,
-      AdfRenderingContext arc,
+      RenderingContext arc,
       FacesBean bean) throws IOException
   {
     ResponseWriter rw = context.getResponseWriter();
@@ -287,7 +287,7 @@
    */
   private void _renderSeparator(
       FacesContext context,
-      AdfRenderingContext arc,
+      RenderingContext arc,
       UIComponent separator,
       FacesBean bean) throws IOException
   {
@@ -320,7 +320,7 @@
    */
   private void _renderTitle(
       FacesContext context,
-      AdfRenderingContext arc,
+      RenderingContext arc,
       UIComponent comp,
       FacesBean bean) throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputFormattedRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputFormattedRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputFormattedRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputFormattedRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,9 +16,8 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
-import java.util.Map;
 import java.util.HashMap;
+import java.util.Map;
 
 import javax.faces.component.UIComponent;
 import javax.faces.context.FacesContext;
@@ -27,8 +26,7 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.output.CoreOutputFormatted;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 public class OutputFormattedRenderer extends ValueRenderer
 {
@@ -46,7 +44,7 @@
 
   protected void encodeBegin(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         comp,
     FacesBean           bean) throws IOException
   {
@@ -59,7 +57,7 @@
 
   public void encodeEnd(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         comp,
     FacesBean           bean) throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputLabelRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputLabelRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputLabelRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputLabelRenderer.java Wed Jul 26 20:39:26 2006
@@ -25,10 +25,9 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.output.CoreOutputLabel;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
-import org.apache.myfaces.trinidadinternal.util.MessageUtils;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
+import org.apache.myfaces.trinidadinternal.util.MessageUtils;
 
 /**
  * Renderer for org.apache.myfaces.trinidad.Label, family org.apache.myfaces.trinidad.Output.
@@ -71,7 +70,7 @@
    */
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   { 
@@ -159,7 +158,7 @@
 
   protected boolean encodeIcons(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     String              messageType,
@@ -198,7 +197,7 @@
   }
 
   protected boolean isLabelTagNeeded(
-    AdfRenderingContext arc, 
+    RenderingContext arc, 
     FacesBean           bean,
     String              forId, 
     int                 accessKeyIndex
@@ -214,7 +213,7 @@
    */
   protected boolean renderMessageSymbol(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Object              type,
     Object              destination,
     Object              anchor,
@@ -275,7 +274,7 @@
   
    protected void renderAllAttributes(
      FacesContext        context,
-     AdfRenderingContext arc,
+     RenderingContext arc,
      FacesBean           bean) throws IOException
    {
      renderAllAttributes(context, arc, bean, false);
@@ -289,7 +288,7 @@
 
   private void _renderIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Icon             icon,
     Object           destination,
     Object           anchor,

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputTextRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputTextRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputTextRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputTextRenderer.java Wed Jul 26 20:39:26 2006
@@ -24,8 +24,7 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.output.CoreOutputText;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.util.nls.StringUtils;
 
 public class OutputTextRenderer extends ValueRenderer
@@ -46,7 +45,7 @@
 
   protected void encodeBegin(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         comp,
     FacesBean           bean) throws IOException
   {
@@ -62,7 +61,7 @@
 
   public void encodeEnd(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         comp,
     FacesBean           bean) throws IOException
   {
@@ -119,7 +118,7 @@
 
   private void _renderDescription(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean
     ) throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputUtils.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputUtils.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputUtils.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/OutputUtils.java Wed Jul 26 20:39:26 2006
@@ -16,9 +16,7 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.awt.Color;
-
 import java.io.IOException;
-
 import java.util.Map;
 
 import javax.faces.component.UIComponent;
@@ -26,9 +24,8 @@
 import javax.faces.context.ResponseWriter;
 
 import org.apache.myfaces.trinidad.util.ArrayMap;
-
 import org.apache.myfaces.trinidadinternal.agent.AdfFacesAgent;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
 
 /**
@@ -60,7 +57,7 @@
 
   public static void renderLayoutTableAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Object              cellspacing,
     Object              tableWidth
     ) throws IOException
@@ -71,7 +68,7 @@
 
   public static void renderLayoutTableAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Object              cellpadding,
     Object              cellspacing,
     Object              tableWidth
@@ -87,7 +84,7 @@
    */
   public static void renderLayoutTableAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Object              cellpadding,
     Object              cellspacing,
     Object              border,
@@ -104,7 +101,7 @@
    */
   public static void renderLayoutTableAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Object              cellpadding,
     Object              cellspacing,
     Object              border,
@@ -130,7 +127,7 @@
   */
   public static void renderAltAndTooltipForImage(
      FacesContext        context,
-     AdfRenderingContext afc,
+     RenderingContext afc,
      Object              textValue
      ) throws IOException
   {
@@ -161,7 +158,7 @@
    * Returns true if the agent supports alt as a tooltip on images
    */
   public static boolean supportsAltRendersTooltipOnImage(
-    AdfRenderingContext     afc
+    RenderingContext     afc
     )
   {
     return Boolean.TRUE.equals(afc.getAgent().getCapability(
@@ -173,7 +170,7 @@
    * vertically with text on the same line.
    */
   public static String getMiddleIconAlignment(
-    AdfRenderingContext arc)
+    RenderingContext arc)
   {
     // =-= AEW I haven't been able to find an image alignment
     // that works well for all browsers.  "absmiddle" looks
@@ -208,7 +205,7 @@
    */
   public static void renderIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Icon                icon,
     Object              shortDesc,
     Object              align
@@ -222,7 +219,7 @@
    */
   public static void renderIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Icon                icon,
     Object              shortDesc,
     Object              align,
@@ -252,7 +249,7 @@
    */
   static public void renderImage(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Object              absoluteUri,
     Object              width,
     Object              height,
@@ -266,7 +263,7 @@
 
   static public void renderImage(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Object              absoluteUri,
     Object              width,
     Object              height,
@@ -301,7 +298,7 @@
    * @todo Add real mechanism for getting the background color
    * if needed.
    */
-  static public Color getBackgroundColor(AdfRenderingContext arc)
+  static public Color getBackgroundColor(RenderingContext arc)
   {
     return Color.WHITE;
   }

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelBoxRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelBoxRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelBoxRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelBoxRenderer.java Wed Jul 26 20:39:26 2006
@@ -19,14 +19,12 @@
 
 import javax.faces.component.UIComponent;
 import javax.faces.context.FacesContext;
-
 import javax.faces.context.ResponseWriter;
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelBox;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 public class PanelBoxRenderer
   extends XhtmlRenderer
@@ -57,7 +55,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -80,7 +78,7 @@
   }
   
   protected void renderAllAttributes(FacesContext context, 
-    AdfRenderingContext arc, 
+    RenderingContext arc, 
     FacesBean bean) throws IOException
   {
     super.renderAllAttributes(context, arc, bean); 
@@ -89,7 +87,7 @@
   
   protected void renderStyleAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean) throws IOException
   {
     renderStyleAttributes(context, arc, bean, _getDefaultStyleClass(bean));
@@ -137,7 +135,7 @@
   
   private void _renderHeaderRow (
     FacesContext context, 
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean bean, 
     Object text,
     Object icon)
@@ -170,7 +168,7 @@
   // contentContainer's child contents.
   private void _renderContentRow(
     FacesContext context, 
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,    
     FacesBean bean
   ) throws IOException

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelFormRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelFormRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelFormRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelFormRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,14 +16,11 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.awt.Dimension;
-
 import java.io.IOException;
-
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
-
 import java.util.Map;
 import java.util.Set;
 
@@ -33,13 +30,12 @@
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
-import org.apache.myfaces.trinidad.component.core.layout.CorePanelForm;
 import org.apache.myfaces.trinidad.component.UIXEditableValue;
 import org.apache.myfaces.trinidad.component.UIXGroup;
 import org.apache.myfaces.trinidad.component.UIXPanel;
-
+import org.apache.myfaces.trinidad.component.core.layout.CorePanelForm;
 import org.apache.myfaces.trinidadinternal.agent.AdfFacesAgent;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 public class PanelFormRenderer extends XhtmlRenderer
 {
@@ -69,7 +65,7 @@
    */
   protected void renderStyleAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean) throws IOException
   {
     renderStyleAttributes(context, arc, bean, 
@@ -132,7 +128,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -199,7 +195,7 @@
   
   private void _encodeChildren(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     List<UIComponent>   footerComponents,
@@ -570,7 +566,7 @@
 
   private void _encodeFormColumns(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     ResponseWriter      rw,
     boolean             startAlignedLabels,
     String              effectiveLabelWidth,
@@ -683,7 +679,7 @@
 
   private static void _encodeGroupDivider(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     ResponseWriter      rw,
     boolean             startAlignedLabels) throws IOException
   {
@@ -706,7 +702,7 @@
 
   private void _encodeFormItem(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     ResponseWriter      rw,
     boolean             startAlignedLabels,
     UIComponent         item) throws IOException
@@ -772,7 +768,7 @@
   
   private static void _encodeBeforeLabelTd(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     ResponseWriter      rw,
     boolean             startAlignedLabels) throws IOException
   {
@@ -799,7 +795,7 @@
    */
   protected static void encodeBetweenLabelAndFieldCells(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     ResponseWriter      rw) throws IOException
   {
     Map requestMap = context.getExternalContext().getRequestMap();

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelGroupRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelGroupRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelGroupRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelGroupRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.List;
 
 import javax.faces.component.UIComponent;
@@ -26,8 +25,7 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelGroup;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 public class PanelGroupRenderer extends XhtmlRenderer
 {
@@ -50,7 +48,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHeaderRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHeaderRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHeaderRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHeaderRenderer.java Wed Jul 26 20:39:26 2006
@@ -24,12 +24,9 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelHeader;
-
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
-import org.apache.myfaces.trinidadinternal.util.IntegerUtils;
-
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
+import org.apache.myfaces.trinidadinternal.util.IntegerUtils;
 
 
 /**
@@ -65,7 +62,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -153,7 +150,7 @@
   // we use the icon specified via the header's ICON_ATTR.
   protected void renderIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     String              messageType) throws IOException
@@ -203,7 +200,7 @@
   * Returns text of header
   */
   protected String getText(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean,
     String              messageType
     )
@@ -260,7 +257,7 @@
 
 
   protected static Number getContextHeaderSize(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Number           defaultValue
     )
   {
@@ -275,7 +272,7 @@
    * Set the size of the header stored on the context
    */
   protected static void setContextHeaderSize(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Number           size
     )
   {
@@ -288,7 +285,7 @@
    * Returns the current depth of the nesting.
    */
   protected static int getHeaderNestLevel(
-    AdfRenderingContext arc
+    RenderingContext arc
     )
   {
     Number n = (Number) arc.getProperties().get(HEADER_NEST_LEVEL);
@@ -299,7 +296,7 @@
 
 
   protected static void incrementHeaderNestLevel(
-    AdfRenderingContext arc
+    RenderingContext arc
     )throws IOException
   {
     arc.getProperties().put(HEADER_NEST_LEVEL,
@@ -307,7 +304,7 @@
   }
 
   protected static void decrementHeaderNestLevel(
-    AdfRenderingContext arc
+    RenderingContext arc
     )throws IOException
   {
     int headerNestLevel = getHeaderNestLevel(arc);
@@ -342,7 +339,7 @@
 
 
   private int _getAndStoreSize(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean)
   {
     Number sizeNumber = getSize(bean);

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHorizontalRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHorizontalRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHorizontalRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelHorizontalRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.List;
 
 import javax.faces.component.UIComponent;
@@ -26,8 +25,7 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelHorizontal;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 public class PanelHorizontalRenderer extends XhtmlRenderer
 {
@@ -51,7 +49,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -96,7 +94,7 @@
    */
   private void _encodeChildren(
     FacesContext context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent  component,
     Object       vAlign,
     Object       hAlign

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelLabelAndMessageRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelLabelAndMessageRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelLabelAndMessageRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelLabelAndMessageRenderer.java Wed Jul 26 20:39:26 2006
@@ -19,14 +19,12 @@
 
 import javax.faces.component.UIComponent;
 import javax.faces.context.FacesContext;
-
 import javax.faces.context.ResponseWriter;
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelLabelAndMessage;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.util.MessageUtils;
 
 
@@ -60,7 +58,7 @@
   
   protected String getLabelFor(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean)
   {
@@ -73,7 +71,7 @@
 
   protected void renderFieldCellContents(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -126,7 +124,7 @@
 
   protected boolean hasMessage(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean)
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelListRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelListRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelListRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelListRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.List;
 
 import javax.faces.component.UIComponent;
@@ -26,9 +25,8 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelList;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
-import org.apache.myfaces.trinidadinternal.renderkit.core.CoreAdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.core.CoreRenderingContext;
 import org.apache.myfaces.trinidadinternal.util.IntegerUtils;
 
 public class PanelListRenderer extends XhtmlRenderer
@@ -53,7 +51,7 @@
    */
   protected void renderStyleAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean) throws IOException
   {
     renderStyleAttributes(context, arc, bean,
@@ -68,7 +66,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -85,13 +83,13 @@
     renderId(context, component);
     renderAllAttributes(context, arc, bean);
 
-    ((CoreAdfRenderingContext) arc).setDefaultLinkStyleDisabled(true);
+    ((CoreRenderingContext) arc).setDefaultLinkStyleDisabled(true);
 
     if (split >= childCount)
       _renderNoColumns(context, arc, component, bean, 0, childCount);
     else
       _renderColumns(context, arc, component, bean, split, childCount);
-    ((CoreAdfRenderingContext) arc).setDefaultLinkStyleDisabled(false);
+    ((CoreRenderingContext) arc).setDefaultLinkStyleDisabled(false);
     writer.endElement("div");
 
   }
@@ -128,7 +126,7 @@
   // multiple columns, and we are rendering a single column.
   private int _renderNoColumns(
     FacesContext context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent  component,
     FacesBean    bean,
     int          start,
@@ -170,7 +168,7 @@
   // render with columns
   private void _renderColumns(
     FacesContext context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent  component,
     FacesBean    bean,
     int          split,
@@ -225,7 +223,7 @@
   }
 
   private int _getMaxColumns(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean bean)
   {
     // get the number of columns
@@ -244,7 +242,7 @@
               SPLIT_DEFAULT;
   }
 
-  private int _getDefaultColumns(AdfRenderingContext arc)
+  private int _getDefaultColumns(RenderingContext arc)
   {
 
     Integer defaultColumns =

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelPartialRootRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelPartialRootRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelPartialRootRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PanelPartialRootRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,29 +16,25 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.Iterator;
 
 import javax.faces.component.UIComponent;
 import javax.faces.context.ExternalContext;
 import javax.faces.context.FacesContext;
 import javax.faces.context.ResponseWriter;
-
 import javax.faces.render.RenderKit;
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelPartialRoot;
+import org.apache.myfaces.trinidad.logging.ADFLogger;
 import org.apache.myfaces.trinidad.render.ExtendedRenderKitService;
 import org.apache.myfaces.trinidad.util.Service;
-
-import org.apache.myfaces.trinidad.logging.ADFLogger;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.ppr.PPRResponseWriter;
+import org.apache.myfaces.trinidadinternal.renderkit.core.ppr.PartialPageContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.ppr.ScriptBufferingResponseWriter;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.jsLibs.LibraryScriptlet;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.jsLibs.Scriptlet;
-import org.apache.myfaces.trinidadinternal.renderkit.core.ppr.PartialPageContext;
 
 
 /**
@@ -66,7 +62,7 @@
 
   protected void renderContent(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -76,7 +72,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -157,7 +153,7 @@
 
   protected void renderAtEnd(
     FacesContext context,
-    AdfRenderingContext arc) throws IOException
+    RenderingContext arc) throws IOException
   {
   }
 
@@ -179,7 +175,7 @@
    */
   private void _renderPartialScripts(
     FacesContext                  context,
-    AdfRenderingContext           arc,
+    RenderingContext           arc,
     ScriptBufferingResponseWriter scriptBufferingWriter) throws IOException
   {
     PartialPageContext pprContext = arc.getPartialPageContext();
@@ -324,14 +320,14 @@
   }
 
   // Is this a partial page rendering pass?
-  protected static boolean isPartialPass(AdfRenderingContext arc)
+  protected static boolean isPartialPass(RenderingContext arc)
   {
     return (PartialPageUtils.isPartialRenderingPass(arc));
   }
 
   protected void renderPPRSupport(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -353,7 +349,7 @@
   // Renders the iframe used to make partial page requests.
   private void _renderPartialIFrame(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component) throws IOException
   {
     // Note: For now we just use the simplest possible strategy -
@@ -440,7 +436,7 @@
   // handling of a partial update.
   private static void _renderPartialBlocking(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component)
     throws IOException
   {
@@ -471,7 +467,7 @@
   // for IE.
   private static void _renderLibraryDownloadElement(
     FacesContext context,
-    AdfRenderingContext arc) throws IOException
+    RenderingContext arc) throws IOException
   {
     // This is to download the libraries from the iframe into the
     // main page on IE.
@@ -503,7 +499,7 @@
 
     protected void outputScriptletContent(
       FacesContext context,
-      AdfRenderingContext arc) throws IOException
+      RenderingContext arc) throws IOException
     {
       ResponseWriter writer = context.getResponseWriter();
 

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PartialPageUtils.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PartialPageUtils.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PartialPageUtils.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PartialPageUtils.java Wed Jul 26 20:39:26 2006
@@ -19,12 +19,9 @@
 
 import javax.faces.context.FacesContext;
 
-import org.apache.myfaces.trinidad.context.AdfFacesContext;
-
+import org.apache.myfaces.trinidad.context.RequestContext;
 import org.apache.myfaces.trinidadinternal.agent.AdfFacesAgent;
-import org.apache.myfaces.trinidadinternal.context.AdfFacesContextBean;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.ppr.PartialPageContext;
 
 /**
@@ -41,7 +38,7 @@
 
   public static boolean isPartialRequest(FacesContext context)
   {
-    return AdfFacesContext.getCurrentInstance().isPartialRequest(context);
+    return RequestContext.getCurrentInstance().isPartialRequest(context);
   }
 
 
@@ -58,7 +55,7 @@
 
   public static PartialPageContext createPartialPageContext(
     FacesContext    context,
-    AdfFacesContext afContext)
+    RequestContext afContext)
   {
     if (isPartialRequest(context))
     {
@@ -73,7 +70,7 @@
    * Returns true if we are performing a partial page render.
    */
   public static boolean isPartialRenderingPass(
-    AdfRenderingContext arc
+    RenderingContext arc
     )
   {
     PartialPageContext pprContext = arc.getPartialPageContext();
@@ -93,7 +90,7 @@
    * (PPR is considered accessible, so we do not check the accessibility mode)
    */
   public static boolean supportsPartialRendering(
-    AdfRenderingContext arc
+    RenderingContext arc
     )
   {
 
@@ -107,7 +104,7 @@
   }
 
   public static boolean supportsBlocking(
-    AdfRenderingContext arc
+    RenderingContext arc
     )
   {
     // At the moment we have blocking solved on IE and Mozilla

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PdaPanelPageHeaderRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PdaPanelPageHeaderRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PdaPanelPageHeaderRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/PdaPanelPageHeaderRenderer.java Wed Jul 26 20:39:26 2006
@@ -20,12 +20,11 @@
 
 import javax.faces.component.UIComponent;
 import javax.faces.context.FacesContext;
-
 import javax.faces.context.ResponseWriter;
+
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.component.core.layout.CorePanelPageHeader;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 
 /**
@@ -48,7 +47,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ProcessUtils.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ProcessUtils.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ProcessUtils.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ProcessUtils.java Wed Jul 26 20:39:26 2006
@@ -20,7 +20,7 @@
 import javax.faces.context.FacesContext;
 import javax.faces.context.ResponseWriter;
 
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.jsLibs.Scriptlet;
 import org.apache.myfaces.trinidadinternal.util.IntegerUtils;
 
@@ -107,7 +107,7 @@
 
   public static void renderNavSubmitScript(
     FacesContext        context,
-    AdfRenderingContext arc
+    RenderingContext arc
     ) throws IOException
   {
     XhtmlUtils.addLib(context, arc, _NAV_SUBMIT_SCRIPTLET);
@@ -115,7 +115,7 @@
 
   public static void renderNavChoiceSubmitScript(
     FacesContext        context,
-    AdfRenderingContext arc
+    RenderingContext arc
     ) throws IOException
   {
     XhtmlUtils.addLib(context, arc,_NAV_CHOICE_SUBMIT_SCRIPTLET);
@@ -138,7 +138,7 @@
 
     protected void outputScriptletContent(
       FacesContext context,
-      AdfRenderingContext arc) throws IOException
+      RenderingContext arc) throws IOException
     {
       context.getResponseWriter().writeText(_NAV_SUBMIT_SCRIPT, null);
     }
@@ -162,7 +162,7 @@
 
     protected void outputScriptletContent(
       FacesContext context,
-      AdfRenderingContext arc) throws IOException
+      RenderingContext arc) throws IOException
     {
       ResponseWriter writer = context.getResponseWriter();
 

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectInputColorRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectInputColorRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectInputColorRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectInputColorRenderer.java Wed Jul 26 20:39:26 2006
@@ -17,10 +17,11 @@
 
 import javax.faces.component.UIComponent;
 import javax.faces.context.FacesContext;
+
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.input.CoreSelectInputColor;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 public class SelectInputColorRenderer extends InputLabelAndMessageRenderer
 {
@@ -42,7 +43,7 @@
   
   protected String getLabelFor(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean)
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectRangeChoiceBarRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectRangeChoiceBarRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectRangeChoiceBarRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SelectRangeChoiceBarRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
@@ -27,25 +26,22 @@
 import javax.faces.context.ResponseWriter;
 import javax.faces.model.SelectItem;
 
-import org.apache.myfaces.trinidad.logging.ADFLogger;
-
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.UIXPanel;
 import org.apache.myfaces.trinidad.component.UIXSelectItem;
 import org.apache.myfaces.trinidad.component.UIXSelectRange;
 import org.apache.myfaces.trinidad.component.core.data.CoreSelectRangeChoiceBar;
-import org.apache.myfaces.trinidad.context.AdfFacesContext;
+import org.apache.myfaces.trinidad.context.RequestContext;
 import org.apache.myfaces.trinidad.event.RangeChangeEvent;
-
+import org.apache.myfaces.trinidad.logging.ADFLogger;
 import org.apache.myfaces.trinidadinternal.agent.AdfFacesAgent;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.core.ppr.PartialPageContext;
 import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
 import org.apache.myfaces.trinidadinternal.util.IntegerUtils;
 import org.apache.myfaces.trinidadinternal.util.Range;
 
-import org.apache.myfaces.trinidadinternal.renderkit.core.ppr.PartialPageContext;
-
 public class SelectRangeChoiceBarRenderer extends XhtmlRenderer
 {
   public SelectRangeChoiceBarRenderer()
@@ -88,7 +84,7 @@
         if (choiceBar.isImmediate())
           context.renderResponse();
 
-        AdfFacesContext.getCurrentInstance().addPartialTarget(component);
+        RequestContext.getCurrentInstance().addPartialTarget(component);
       }
     }
   }
@@ -271,7 +267,7 @@
    */
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -577,7 +573,7 @@
   /**
    * render form value needed values and javascript code.
    */
-  public static void addHiddenFields(AdfRenderingContext arc)
+  public static void addHiddenFields(RenderingContext arc)
   {
     FormData fData = arc.getFormData();
     fData.addNeededValue(XhtmlConstants.EVENT_PARAM);
@@ -588,7 +584,7 @@
 
   private void _renderChoice(
    FacesContext        context,
-   AdfRenderingContext arc,
+   RenderingContext arc,
    UIComponent         component,
    String              id,
    String              source,
@@ -718,7 +714,7 @@
    */
   private int _getItems(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     List                items,
     long                minValue, long maxValue, long value,
@@ -875,7 +871,7 @@
   }
 
   private SelectItem _createShowAllSelectItem(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     long                maxValue)
   {
     String[] parameters = new String[]{IntegerUtils.getString(maxValue)};
@@ -890,7 +886,7 @@
   // create a choice option when max value is known
   private SelectItem _createNavigationItem(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     long             blockStart,
     int              blockSize,
@@ -927,7 +923,7 @@
   // create one of the text links for navigation
   private void _renderLink(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     boolean             isNext,
     String              onclick,
     int                 records,
@@ -975,7 +971,7 @@
   /**
    */
   protected Icon getIcon(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     boolean             isNext,
     boolean             isEnabled
     )
@@ -1031,7 +1027,7 @@
    */
   private void _renderArrow(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     Icon                icon,
     boolean             isNext,
     String              onclick) throws IOException
@@ -1059,7 +1055,7 @@
    * in a table navigation bar.
    */
   protected String getBlockString(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     boolean             isNext,
     int                 numRecords
     )
@@ -1096,7 +1092,7 @@
    */
   private String _getRangeString(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent      component,
     long             start,
     int              visibleItemCount,
@@ -1249,7 +1245,7 @@
    */
   protected void renderItemSpacer(
    FacesContext context,
-   AdfRenderingContext arc) throws IOException
+   RenderingContext arc) throws IOException
   {
     if (arc.getAgent().getAgentType() == AdfFacesAgent.TYPE_PDA)
     {
@@ -1267,7 +1263,7 @@
    */
   private void _renderSpacerCell(
     FacesContext       context,
-    AdfRenderingContext arc
+    RenderingContext arc
     ) throws IOException
   {
     ResponseWriter writer = context.getResponseWriter();
@@ -1293,7 +1289,7 @@
   }
 
   private String _getIDForFocus(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     String              baseId
     )
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailHeaderRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailHeaderRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailHeaderRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailHeaderRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.HashMap;
 import java.util.Map;
 
@@ -26,8 +25,7 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CoreShowDetailHeader;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.CoreRenderer;
 
 public class ShowDetailHeaderRenderer
@@ -55,7 +53,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -75,7 +73,7 @@
     }
   }
 
-  protected void renderIcon(FacesContext context, AdfRenderingContext arc, 
+  protected void renderIcon(FacesContext context, RenderingContext arc, 
                             UIComponent component, FacesBean bean, String messageType)
     throws IOException
   {
@@ -116,7 +114,7 @@
     }
 
     protected void renderAllAttributes(FacesContext context, 
-                                       AdfRenderingContext arc, 
+                                       RenderingContext arc, 
                                        FacesBean bean)
       throws IOException
     {
@@ -127,7 +125,7 @@
       return true;
     }
 
-    protected String getDisclosureText(AdfRenderingContext arc, 
+    protected String getDisclosureText(RenderingContext arc, 
                                        FacesBean bean, boolean disclosed)
     {
       return null;

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailItemRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailItemRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailItemRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailItemRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.Map;
 
 import javax.faces.component.UIComponent;
@@ -26,10 +25,9 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CoreShowDetailItem;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidad.context.RequestContext;
 import org.apache.myfaces.trinidad.event.DisclosureEvent;
-import org.apache.myfaces.trinidad.context.AdfFacesContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 public class ShowDetailItemRenderer extends XhtmlRenderer
 {
@@ -63,7 +61,7 @@
       {
         boolean isDisclosed = XhtmlConstants.SHOW_EVENT.equals(event);
         (new DisclosureEvent(component, isDisclosed)).queue();
-        AdfFacesContext.getCurrentInstance().addPartialTarget(component);
+        RequestContext.getCurrentInstance().addPartialTarget(component);
       }
     }
   }
@@ -85,7 +83,7 @@
 
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/ShowDetailRenderer.java Wed Jul 26 20:39:26 2006
@@ -24,10 +24,9 @@
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.layout.CoreShowDetail;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
-import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
 import org.apache.myfaces.trinidad.logging.ADFLogger;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
+import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
 
 /**
  * This needs to be massively cleaned up...
@@ -58,7 +57,7 @@
    */
   protected void encodeAll(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -130,7 +129,7 @@
 
   protected void renderPromptStart(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -160,7 +159,7 @@
 
   static public void renderDisclosureIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     boolean             disclosed,
     String              disclosedAltTextKey,
     String              undisclosedAltTextKey) throws IOException
@@ -183,7 +182,7 @@
 
   protected void renderDisclosureIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     boolean             disclosed) throws IOException
   {
     renderDisclosureIcon(context, arc, disclosed,
@@ -203,7 +202,7 @@
 
   // Returns the disclosure Icon
   private static Icon _getDisclosureIcon(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     boolean             disclosed
     )
   {
@@ -215,7 +214,7 @@
   }
 
   protected String getDisclosureText(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean,
     boolean             disclosed)
   {
@@ -252,7 +251,7 @@
 
   private void _renderScripts(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component) throws IOException
   {
     if (!supportsNavigation(arc))
@@ -338,7 +337,7 @@
 
   private void _renderLinkStart(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     String           onclickString ) throws IOException
   {
     if (!supportsNavigation(arc))
@@ -352,7 +351,7 @@
 
   private String _generateOnClickString(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     boolean             disclosed)
@@ -406,7 +405,7 @@
 
   private void _renderLinkEnd(
     FacesContext        context,
-    AdfRenderingContext arc) throws IOException
+    RenderingContext arc) throws IOException
   {
     if (!supportsNavigation(arc))
       return;

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputFileRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputFileRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputFileRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputFileRenderer.java Wed Jul 26 20:39:26 2006
@@ -19,10 +19,8 @@
 import javax.faces.context.FacesContext;
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
-
 import org.apache.myfaces.trinidad.component.core.input.CoreInputFile;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.webapp.UploadedFiles;
 
 /**
@@ -136,7 +134,7 @@
     return "af|inputFile::content";
   }
 
-  protected Integer getDefaultColumns(AdfRenderingContext arc, FacesBean bean)
+  protected Integer getDefaultColumns(RenderingContext arc, FacesBean bean)
   {
     return null;
   }

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputTextRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputTextRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputTextRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleInputTextRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.text.BreakIterator;
 
 import javax.faces.component.UIComponent;
@@ -25,11 +24,9 @@
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
-
 import org.apache.myfaces.trinidad.component.core.input.CoreInputText;
-
 import org.apache.myfaces.trinidadinternal.agent.AdfFacesAgent;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.util.IntegerUtils;
 
 /**
@@ -89,7 +86,7 @@
 
   protected void encodeAllAsElement(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -154,7 +151,7 @@
        
   protected void renderAllAttributes(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean,
     boolean             renderStyleAttrs) throws IOException
   {
@@ -263,7 +260,7 @@
    * Returns the default number of text input columns
    * =-=AEW MOVE ONTO BEAN TYPE?
    */
-  protected Integer getDefaultColumns(AdfRenderingContext arc, FacesBean bean)
+  protected Integer getDefaultColumns(RenderingContext arc, FacesBean bean)
   {
     if (arc.getAgent().getAgentType() == AdfFacesAgent.TYPE_PDA)
       return _DEFAULT_PDA_COLUMNS;
@@ -292,7 +289,7 @@
 
   protected void encodeAllAsNonElement(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -333,7 +330,7 @@
    */
   protected void renderNonElementContent(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -343,7 +340,7 @@
 
   protected void renderContent(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     boolean             renderAsElement,
@@ -555,7 +552,7 @@
     if (isTextArea(bean) &&
         getReadOnly(FacesContext.getCurrentInstance(), bean))
     {
-      AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+      RenderingContext arc = RenderingContext.getCurrentInstance();
       if (!supportsReadonlyFormElements(arc))
       {
         onfocus = (String) XhtmlUtils.getChainedJS("this.blur()",
@@ -574,7 +571,7 @@
     String onchange = super.getOnchange(bean);
     if (isAutoSubmit(bean))
     {
-      AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+      RenderingContext arc = RenderingContext.getCurrentInstance();
       String source = LabelAndMessageRenderer.__getCachedClientId(arc);
       boolean immediate = isImmediate(bean);
       String auto = AutoSubmitUtils.getSubmitScript(arc, source, immediate);
@@ -665,7 +662,7 @@
    * @todo RENABLE ONFOCUS HACK
    */
   protected boolean renderReadOnlyAsElement(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean)
   {
     // We render read-only single-line input fields as plain text

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanCheckboxRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanCheckboxRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanCheckboxRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanCheckboxRenderer.java Wed Jul 26 20:39:26 2006
@@ -20,7 +20,7 @@
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.component.core.input.CoreSelectBooleanCheckbox;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 /**
  */
@@ -55,7 +55,7 @@
   //encode
   //**********************
 
-  protected Object getValueAttr(AdfRenderingContext arc)
+  protected Object getValueAttr(RenderingContext arc)
   {
     // HTML 3.2 specification, default value for checkboxes
     return "t";

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRadioRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRadioRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRadioRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRadioRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,14 +16,15 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
+
 import javax.faces.component.UIComponent;
 import javax.faces.context.FacesContext;
-
 import javax.faces.context.ResponseWriter;
+
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.input.CoreSelectBooleanRadio;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 
 /**
  */
@@ -71,7 +72,7 @@
   //encode
   //**********************
 
-  protected Object getValueAttr(AdfRenderingContext arc)
+  protected Object getValueAttr(RenderingContext arc)
   {
     return arc.getCurrentClientId();
   }
@@ -115,7 +116,7 @@
 
   protected void renderNameAttribute(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean
     )throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectBooleanRenderer.java Wed Jul 26 20:39:26 2006
@@ -23,8 +23,7 @@
 
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
-
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.CoreRendererUtils;
 import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
 
@@ -50,7 +49,7 @@
   //**********************
 
 
-  abstract protected Object getValueAttr(AdfRenderingContext arc);
+  abstract protected Object getValueAttr(RenderingContext arc);
 
   abstract protected Object getType();
 
@@ -66,7 +65,7 @@
 
   protected void renderNameAttribute(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean
     )throws IOException
   {
@@ -79,7 +78,7 @@
    */
   protected void encodeAllAsElement(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -175,7 +174,7 @@
 
   protected void encodeAllAsNonElement(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -254,7 +253,7 @@
 
   protected void renderAccessKeyAttribute(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     FacesBean           bean) throws IOException
   {
   }  
@@ -264,7 +263,7 @@
    */
   protected void renderText(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     boolean             renderAccessKeys,
@@ -301,7 +300,7 @@
     FacesBean bean
   )
   {
-    AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+    RenderingContext arc = RenderingContext.getCurrentInstance();
     String source = LabelAndMessageRenderer.__getCachedClientId(arc);
     boolean immediate = isImmediate(bean);
     boolean isRadio = isRadio();
@@ -347,7 +346,7 @@
    * it does not have any text.
    */
   private boolean _isLabelTagRendered(
-    AdfRenderingContext arc,
+    RenderingContext arc,
     String              text,
     char                accessKey
     )
@@ -367,7 +366,7 @@
    */
   private void _renderPartialId(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     String              clientId
   )throws IOException
   {

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputColorRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputColorRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputColorRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputColorRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,9 +16,7 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.awt.Color;
-
 import java.io.IOException;
-
 import java.util.HashMap;
 import java.util.Map;
 
@@ -28,23 +26,20 @@
 import javax.faces.convert.Converter;
 import javax.faces.convert.ConverterException;
 
-import org.apache.myfaces.trinidad.logging.ADFLogger;
-
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.input.CoreSelectInputColor;
-import org.apache.myfaces.trinidad.context.AdfFacesContext;
+import org.apache.myfaces.trinidad.context.RequestContext;
 import org.apache.myfaces.trinidad.event.ReturnEvent;
-
+import org.apache.myfaces.trinidad.logging.ADFLogger;
 import org.apache.myfaces.trinidadinternal.agent.AdfFacesAgent;
 import org.apache.myfaces.trinidadinternal.convert.ColorConverter;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.CoreRendererUtils;
 import org.apache.myfaces.trinidadinternal.renderkit.core.pages.GenericEntry;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.jsLibs.AliasedScriptlet;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.jsLibs.ColorFieldInfoScriptlet;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.jsLibs.ConfigurationScriptlet;
-
 import org.apache.myfaces.trinidadinternal.skin.icon.Icon;
 import org.apache.myfaces.trinidadinternal.style.util.CSSUtils;
 import org.apache.myfaces.trinidadinternal.util.IntegerUtils;
@@ -101,7 +96,7 @@
       }
 
 
-      AdfFacesContext afContext = AdfFacesContext.getCurrentInstance();
+      RequestContext afContext = RequestContext.getCurrentInstance();
 
       // =-=AEW Parameters?  Shouldn't we pass in the color?
       Map parameters = null;
@@ -155,7 +150,7 @@
 
   protected void encodeAllAsElement(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -178,7 +173,7 @@
 
   protected void renderTextField(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -212,7 +207,7 @@
 
   protected void renderContent(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     boolean             renderAsElement,
@@ -230,7 +225,7 @@
 
   protected void renderAfterTextField(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -251,7 +246,7 @@
 
   protected void renderIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -281,7 +276,7 @@
 
   protected String getLaunchOnclick(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -313,7 +308,7 @@
   protected String getOnfocus(FacesBean bean)
   {
     String onfocus = super.getOnfocus(bean);
-    AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+    RenderingContext arc = RenderingContext.getCurrentInstance();
     if (!_supportsSwatchAndChooser(arc))
       return onfocus;
 
@@ -340,7 +335,7 @@
   protected String getOnblur(FacesBean bean)
   {
     String onblur = super.getOnblur(bean);
-    if (!_supportsSwatchAndChooser(AdfRenderingContext.getCurrentInstance()))
+    if (!_supportsSwatchAndChooser(RenderingContext.getCurrentInstance()))
       return XhtmlUtils.getChainedJS(_AUTO_FORMAT_SCRIPT,
                                      onblur, false);
 
@@ -351,7 +346,7 @@
 
 
 
-  protected Integer getDefaultColumns(AdfRenderingContext arc, FacesBean bean)
+  protected Integer getDefaultColumns(RenderingContext arc, FacesBean bean)
   {
     Converter converter = getConverter(bean);
 
@@ -403,7 +398,7 @@
     return "af|selectInputColor::content";
   }
 
-  private String _getChooseId(AdfRenderingContext arc)
+  private String _getChooseId(RenderingContext arc)
   {
     return (String) arc.getProperties().get(_CACHED_CHOOSE_ID);
   }
@@ -420,21 +415,21 @@
   }
 
   // On PDAs, we only support a simple text field
-  private boolean _supportsSwatchAndChooser(AdfRenderingContext arc)
+  private boolean _supportsSwatchAndChooser(RenderingContext arc)
   {
     return (arc.getAgent().getAgentType() != AdfFacesAgent.TYPE_PDA);
   }
 
   protected String getSearchDesc(FacesBean bean)
   {
-    AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+    RenderingContext arc = RenderingContext.getCurrentInstance();
     if (isInaccessibleMode(arc))
       return null;
 
     return arc.getTranslatedString(_LAUNCH_PICKER_TIP_KEY);
   }
 
-  private String _getColorSwatchId(AdfRenderingContext arc)
+  private String _getColorSwatchId(RenderingContext arc)
   {
     return arc.getCurrentClientId() + "$sw";
   }
@@ -442,7 +437,7 @@
 
   private void _renderColorSwatch(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean,
     boolean             editable) throws IOException
@@ -533,7 +528,7 @@
   // a given chooseId, and if so renders a script
   private void _renderFirstColorFieldScript(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     String              chooseId
     ) throws IOException

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputDateRenderer.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputDateRenderer.java?rev=425942&r1=425941&r2=425942&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputDateRenderer.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/trinidad/trinidad-impl/src/main/java/org/apache/myfaces/trinidadinternal/renderkit/core/xhtml/SimpleSelectInputDateRenderer.java Wed Jul 26 20:39:26 2006
@@ -16,7 +16,6 @@
 package org.apache.myfaces.trinidadinternal.renderkit.core.xhtml;
 
 import java.io.IOException;
-
 import java.util.Calendar;
 import java.util.Date;
 import java.util.HashMap;
@@ -31,18 +30,16 @@
 import javax.faces.convert.ConverterException;
 import javax.faces.convert.DateTimeConverter;
 
-import org.apache.myfaces.trinidad.logging.ADFLogger;
-
 import org.apache.myfaces.trinidad.bean.FacesBean;
 import org.apache.myfaces.trinidad.bean.PropertyKey;
 import org.apache.myfaces.trinidad.component.core.input.CoreSelectInputDate;
-import org.apache.myfaces.trinidad.context.AdfFacesContext;
+import org.apache.myfaces.trinidad.context.RequestContext;
 import org.apache.myfaces.trinidad.event.ReturnEvent;
+import org.apache.myfaces.trinidad.logging.ADFLogger;
 import org.apache.myfaces.trinidad.validator.DateTimeRangeValidator;
-
 import org.apache.myfaces.trinidadinternal.agent.AdfFacesAgent;
 import org.apache.myfaces.trinidadinternal.convert.GenericConverterFactory;
-import org.apache.myfaces.trinidadinternal.renderkit.AdfRenderingContext;
+import org.apache.myfaces.trinidadinternal.renderkit.RenderingContext;
 import org.apache.myfaces.trinidadinternal.renderkit.core.CoreRendererUtils;
 import org.apache.myfaces.trinidadinternal.renderkit.core.pages.GenericEntry;
 import org.apache.myfaces.trinidadinternal.renderkit.core.xhtml.jsLibs.ConfigurationScriptlet;
@@ -104,7 +101,7 @@
       }
 
 
-      AdfFacesContext afContext = AdfFacesContext.getCurrentInstance();
+      RequestContext afContext = RequestContext.getCurrentInstance();
       DateTimeRangeValidator dtrv = _findDateTimeRangeValidator(bean);
 
       if (date == null)
@@ -172,7 +169,7 @@
 
   protected void encodeAllAsElement(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -193,7 +190,7 @@
 
   protected void renderIcon(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -244,7 +241,7 @@
         {
             TimeZone tz = null;
 
-            AdfFacesContext adfFacesContext = AdfFacesContext.getCurrentInstance();
+            RequestContext adfFacesContext = RequestContext.getCurrentInstance();
             tz = adfFacesContext.getTimeZone();
             if(tz == null)
             {
@@ -261,7 +258,7 @@
   protected String getOnblur(FacesBean bean)
   {
     String onblur = super.getOnblur(bean);
-    AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+    RenderingContext arc = RenderingContext.getCurrentInstance();
     String chooseId = _getChooseId(arc);
 
     int length = _BLUR_PREFIX.length() + 4;
@@ -286,7 +283,7 @@
   protected String getOnfocus(FacesBean bean)
   {
     String onfocus = super.getOnfocus(bean);
-    AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+    RenderingContext arc = RenderingContext.getCurrentInstance();
     String chooseId = _getChooseId(arc);
 
     // The special _dff handler is only needed for date fields
@@ -320,7 +317,7 @@
 
   protected String getLaunchOnclick(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     FacesBean           bean) throws IOException
   {
@@ -380,7 +377,7 @@
   }
 
 
-  protected Integer getDefaultColumns(AdfRenderingContext arc, FacesBean bean)
+  protected Integer getDefaultColumns(RenderingContext arc, FacesBean bean)
   {
     Converter converter = getConverter(bean);
 
@@ -410,7 +407,7 @@
 
   protected String getSearchDesc(FacesBean bean)
   {
-    AdfRenderingContext arc = AdfRenderingContext.getCurrentInstance();
+    RenderingContext arc = RenderingContext.getCurrentInstance();
     if (isInaccessibleMode(arc))
       return null;
 
@@ -428,7 +425,7 @@
     return "af|selectInputDate::content";
   }
 
-  private String _getChooseId(AdfRenderingContext arc)
+  private String _getChooseId(RenderingContext arc)
   {
     return (String) arc.getProperties().get(_CACHED_CHOOSE_ID);
   }
@@ -449,7 +446,7 @@
   // it.
   private void _checkIfActive(
     FacesContext        context,
-    AdfRenderingContext arc,
+    RenderingContext arc,
     UIComponent         component,
     String              chooseId
     ) throws IOException
@@ -533,7 +530,7 @@
 
   /**
    * Adjust the specified date, which is in server timeZone to the timeZone
    * found in AdfFacesContext and return the new date long value.
    */
   private static long _adjustTimeZone(Date date)
   {
@@ -547,15 +544,15 @@
                    calendar.get(Calendar.DST_OFFSET);
     // get the timeZone specified in adf-faces-config, if any or the
     // client timeZone and find out the difference in timeZone
-    TimeZone timeZone = AdfFacesContext.getCurrentInstance().getTimeZone();
+    TimeZone timeZone = RequestContext.getCurrentInstance().getTimeZone();
     if(timeZone == null)
     {
         timeZone = TimeZone.getDefault();
     }
 
     // then, adjust for the "local" time zone (either the client's, as
     // specified in AdfFacesContext, or the server's if it wasn't specified
     // in AdfFacesContext)
     tzOffset -= timeZone.getOffset(dateValueInMs);
 
     // make sure that adjusting to correct timeZone doesn't take the
@@ -599,7 +596,7 @@
 
     protected void outputScriptletContent(
       FacesContext context,
-      AdfRenderingContext arc)
+      RenderingContext arc)
       throws IOException
     {
       // get the tzOffset for the current date. I will compare this with
@@ -533,7 +530,7 @@
   /**
    * Adjust the specified date, which is in server timeZone to the timeZone
-   * found in AdfFacesContext and return the new date long value.
+   * found in RequestContext and return the new date long value.
    */
   private static long _adjustTimeZone(Date date)
@@ -547,15 +544,15 @@
 
     // then, adjust for the "local" time zone (either the client's, as
-    // specified in AdfFacesContext, or the server's if it wasn't specified
-    // in AdfFacesContext)
+    // specified in RequestContext, or the server's if it wasn't specified
+    // in RequestContext)
     tzOffset -= timeZone.getOffset(dateValueInMs);
 